summaryrefslogtreecommitdiffstats
path: root/siplib/sip-tqt.h
diff options
context:
space:
mode:
Diffstat (limited to 'siplib/sip-tqt.h')
-rw-r--r--siplib/sip-tqt.h46
1 files changed, 23 insertions, 23 deletions
diff --git a/siplib/sip-tqt.h b/siplib/sip-tqt.h
index 7fb0bb5..f8fc861 100644
--- a/siplib/sip-tqt.h
+++ b/siplib/sip-tqt.h
@@ -856,7 +856,7 @@ typedef struct _sipExportedModuleDef {
sipImportedModuleDef *em_imports;
/* The optional TQt support API. */
- struct _sipTQtAPI *em_qt_api;
+ struct _sipTQtAPI *em_tqt_api;
/* The number of types. */
int em_nrtypes;
@@ -1298,22 +1298,22 @@ typedef struct _sipAPIDef {
* The API implementing the optional TQt support.
*/
typedef struct _sipTQtAPI {
- sipTypeDef **qt_qobject;
- void *(*qt_create_universal_signal)(void *, const char **);
- void *(*qt_find_universal_signal)(void *, const char **);
- void *(*qt_create_universal_slot)(struct _sipWrapper *, const char *,
+ sipTypeDef **tqt_tqobject;
+ void *(*tqt_create_universal_signal)(void *, const char **);
+ void *(*tqt_find_universal_signal)(void *, const char **);
+ void *(*tqt_create_universal_slot)(struct _sipWrapper *, const char *,
PyObject *, const char *, const char **, int);
- void (*qt_destroy_universal_slot)(void *);
- void *(*qt_find_slot)(void *, const char *, PyObject *, const char *,
+ void (*tqt_destroy_universal_slot)(void *);
+ void *(*tqt_find_slot)(void *, const char *, PyObject *, const char *,
const char **);
- int (*qt_connect)(void *, const char *, void *, const char *, int);
- int (*qt_disconnect)(void *, const char *, void *, const char *);
- int (*qt_same_name)(const char *, const char *);
- sipSlot *(*qt_find_sipslot)(void *, void **);
+ int (*tqt_connect)(void *, const char *, void *, const char *, int);
+ int (*tqt_disconnect)(void *, const char *, void *, const char *);
+ int (*tqt_same_name)(const char *, const char *);
+ sipSlot *(*tqt_find_sipslot)(void *, void **);
int (*tqt_emit_signal)(PyObject *, const char *, PyObject *);
- int (*qt_connect_py_signal)(PyObject *, const char *, PyObject *,
+ int (*tqt_connect_py_signal)(PyObject *, const char *, PyObject *,
const char *);
- void (*qt_disconnect_py_signal)(PyObject *, const char *, PyObject *,
+ void (*tqt_disconnect_py_signal)(PyObject *, const char *, PyObject *,
const char *);
} sipTQtAPI;
@@ -1420,29 +1420,29 @@ typedef struct _sipTQtAPI {
/*
* The following are PyTQt3-specific extensions. In SIP-TQt v5 they will be pushed
* out to a plugin supplied by PyTQt3.
*/
-typedef int (*pyqt3EmitFunc)(sipSimpleWrapper *, PyObject *);
+typedef int (*pytqtEmitFunc)(sipSimpleWrapper *, PyObject *);
/*
* Maps the name of a TQt signal to a wrapper function to emit it.
*/
-typedef struct _pyqt3QtSignal {
+typedef struct _pytqtTQtSignal {
/* The signal name. */
const char *st_name;
/* The emitter function. */
- pyqt3EmitFunc st_emitfunc;
-} pyqt3QtSignal;
+ pytqtEmitFunc st_emitfunc;
+} pytqtTQtSignal;
/*
- * This is the PyTQt3-specific extension to the generated class type structure.
+ * This is the PyTQt-specific extension to the generated class type structure.
*/
-typedef struct _pyqt3ClassTypeDef {
+typedef struct _pytqtClassTypeDef {
/*
* The super-type structure. This must be first in the structure so that
* it can be cast to sipClassTypeDef *.
@@ -1450,8 +1450,8 @@ typedef struct _pyqt3ClassTypeDef {
sipClassTypeDef super;
/* The emit table for TQt signals. */
- pyqt3QtSignal *qt3_emit;
-} pyqt3ClassTypeDef;
+ pytqtTQtSignal *tqt_emit;
+} pytqtClassTypeDef;
/*
@@ -1420,29 +1420,29 @@ typedef struct _sipTQtAPI {
/*
- * The following are PyTQt3-specific extensions. In SIP-TQt v5 they will be pushed
- * out to a plugin supplied by PyTQt3.
+ * The following are PyTQt-specific extensions. In SIP-TQt v5 they will be pushed
+ * out to a plugin supplied by PyTQt.
*/